@@ -14,6 +14,7 @@ import os
 import parse_datetime
 import glob
 import locale
+import types
 
 try:
     sorted( [] )
@@ -23,6 +24,11 @@ except NameError:
         list_out.sort()
         return list_out
 
+if hasattr( types, 'StringTypes' ):
+    StringTypes = types.StringTypes
+else:
+    StringTypes = [type( '' )]
+
 class CommandError( Exception ):
     def __init__( self, reason ):
         Exception.__init__( self )
@@ -145,6 +151,32 @@ if hasattr( pysvn.wc_notify_action, 'property_added' ):
     wc_notify_action_map[ pysvn.wc_notify_action.tree_conflict ] = 'tree_conflict'
     wc_notify_action_map[ pysvn.wc_notify_action.failed_external ] = 'failed_external'
 
+if hasattr( pysvn.wc_notify_action, 'update_started' ):
+    wc_notify_action_map[ pysvn.wc_notify_action.update_started ] = 'update_started'
+    wc_notify_action_map[ pysvn.wc_notify_action.update_skip_obstruction ] = 'update_skip_obstruction'
+    wc_notify_action_map[ pysvn.wc_notify_action.update_skip_working_only ] = 'update_skip_working_only'
+    wc_notify_action_map[ pysvn.wc_notify_action.update_external_removed ] = 'update_external_removed'
+    wc_notify_action_map[ pysvn.wc_notify_action.update_shadowed_add ] = 'update_shadowed_add'
+    wc_notify_action_map[ pysvn.wc_notify_action.update_shadowed_update ] = 'update_shadowed_update'
+    wc_notify_action_map[ pysvn.wc_notify_action.update_shadowed_delete ] = 'update_shadowed_delete'
+    wc_notify_action_map[ pysvn.wc_notify_action.merge_record_info ] = 'merge_record_info'
+    wc_notify_action_map[ pysvn.wc_notify_action.upgraded_path ] = 'upgraded_path'
+    wc_notify_action_map[ pysvn.wc_notify_action.merge_record_info_begin ] = 'merge_record_info_begin'
+    wc_notify_action_map[ pysvn.wc_notify_action.merge_elide_info ] = 'merge_elide_info'
+    wc_notify_action_map[ pysvn.wc_notify_action.patch ] = 'patch'
+    wc_notify_action_map[ pysvn.wc_notify_action.patch_applied_hunk ] = 'patch_applied_hunk'
+    wc_notify_action_map[ pysvn.wc_notify_action.patch_rejected_hunk ] = 'patch_rejected_hunk'
+    wc_notify_action_map[ pysvn.wc_notify_action.patch_hunk_already_applied ] = 'patch_hunk_already_applied'
+    wc_notify_action_map[ pysvn.wc_notify_action.commit_copied ] = 'commit_copied'
+    wc_notify_action_map[ pysvn.wc_notify_action.commit_copied_replaced ] = 'commit_copied_replaced'
+    wc_notify_action_map[ pysvn.wc_notify_action.url_redirect ] = 'url_redirect'
+    wc_notify_action_map[ pysvn.wc_notify_action.path_nonexistent ] = 'path_nonexistent'
+    wc_notify_action_map[ pysvn.wc_notify_action.exclude ] = 'exclude'
+    wc_notify_action_map[ pysvn.wc_notify_action.failed_conflict ] = 'failed_conflict'
+    wc_notify_action_map[ pysvn.wc_notify_action.failed_missing ] = 'failed_missing'
+    wc_notify_action_map[ pysvn.wc_notify_action.failed_out_of_date ] = 'failed_out_of_date'
+    wc_notify_action_map[ pysvn.wc_notify_action.failed_no_parent ] = 'failed_no_parent'
+
 class SvnCommand:
     def __init__( self, progname ):
         self.progname = progname
@@ -213,7 +245,10 @@ class SvnCommand:
     def callback_conflict_resolver( self, arg_dict ):
         print( 'callback_conflict_resolver' )
         for key in sorted( arg_dict.keys() ):
-            print( '  %s: %r' % (key, arg_dict[ key ]) )
+            value = arg_dict[ key ]
+            if type(value) not in StringTypes:
+                value = repr(value)
+            print( '  %s: %s' % (key, value) )
 
         return pysvn.wc_conflict_choice.postpone, None, False
 
@@ -437,7 +472,7 @@ class SvnCommand:
             positional_args.append( '.' )
 
         path = positional_args[0]
-
+    
         entry = self.client.info( path )
 
         print( 'Path: %s' % path )
@@ -945,6 +980,7 @@ class SvnCommand:
         positional_args = args.getPositionalArgs( 0 )
         if len(positional_args) == 0:
             positional_args.append( '.' )
+
         rev_list = self.client.update( positional_args[0], recurse=recurse )
         self.printNotifyMessages()
         if type(rev_list) == type([]) and len(rev_list) != 1:
