@@ -500,6 +500,36 @@ void test_Tuple()
 
     Py::List list1( tuple1 );
     test_assert( "tuple construct from list", list1.size(), tuple1.size() );
+
+    Py::TupleN t0;
+    test_assert( "TupleN construction", 0, t0.size() );
+    Py::TupleN t1(  Py::Long( 1 ) );
+    test_assert( "TupleN construction", 1, t1.size() );
+    Py::TupleN t2(  Py::Long( 1 ), Py::Long( 2 ) );
+    test_assert( "TupleN construction", 2, t2.size() );
+    Py::TupleN t3(  Py::Long( 1 ), Py::Long( 2 ), Py::Long( 3 ) );
+    test_assert( "TupleN construction", 3, t3.size() );
+    Py::TupleN t4(  Py::Long( 1 ), Py::Long( 2 ), Py::Long( 3 ),
+                    Py::Long( 4 ) );
+    test_assert( "TupleN construction", 4, t4.size() );
+    Py::TupleN t5(  Py::Long( 1 ), Py::Long( 2 ), Py::Long( 3 ),
+                    Py::Long( 4 ), Py::Long( 5 ) );
+    test_assert( "TupleN construction", 5, t5.size() );
+    Py::TupleN t6(  Py::Long( 1 ), Py::Long( 2 ), Py::Long( 3 ),
+                    Py::Long( 4 ), Py::Long( 5 ), Py::Long( 6 ) );
+    test_assert( "TupleN construction", 6, t6.size() );
+    Py::TupleN t7(  Py::Long( 1 ), Py::Long( 2 ), Py::Long( 3 ),
+                    Py::Long( 4 ), Py::Long( 5 ), Py::Long( 6 ),
+                    Py::Long( 7 ) );
+    test_assert( "TupleN construction", 7, t7.size() );
+    Py::TupleN t8(  Py::Long( 1 ), Py::Long( 2 ), Py::Long( 3 ),
+                    Py::Long( 4 ), Py::Long( 5 ), Py::Long( 6 ),
+                    Py::Long( 7 ), Py::Long( 8 ) );
+    test_assert( "TupleN construction", 8, t8.size() );
+    Py::TupleN t9(  Py::Long( 1 ), Py::Long( 2 ), Py::Long( 3 ),
+                    Py::Long( 4 ), Py::Long( 5 ), Py::Long( 6 ),
+                    Py::Long( 7 ), Py::Long( 8 ), Py::Long( 9 ) );
+    test_assert( "TupleN construction", 9, t9.size() );
 }
 
 void test_Dict()
@@ -813,7 +843,13 @@ private:
     }
 };
 
-extern "C" PyObject *PyInit_example()
+#if defined( _WIN32 )
+#define EXPORT_SYMBOL __declspec( dllexport )
+#else
+#define EXPORT_SYMBOL
+#endif
+
+extern "C" EXPORT_SYMBOL PyObject *PyInit_example()
 {
 #if defined(PY_WIN32_DELAYLOAD_PYTHON_DLL)
     Py::InitialisePythonIndirectPy::Interface();
@@ -825,7 +861,7 @@ extern "C" PyObject *PyInit_example()
 }
 
 // symbol required for the debug version
-extern "C" PyObject *PyInit_example_d()
+extern "C" EXPORT_SYMBOL PyObject *PyInit_example_d()
 { 
     return PyInit_example();
 }
