@@ -378,8 +378,6 @@ Py::Object pysvn_client::cmd_info( const Py::Tuple &a_args, const Py::Dict &a_kw
 
     try
     {
-        std::string norm_path( svnNormalisedIfPath( path, pool ) );
-
         checkThreadPermission();
 
         PythonAllowThreads permission( m_context );
@@ -387,8 +385,11 @@ Py::Object pysvn_client::cmd_info( const Py::Tuple &a_args, const Py::Dict &a_kw
         svn_wc_adm_access_t *adm_access = NULL;
 
 #if defined( PYSVN_HAS_WC_ADM_PROBE_OPEN3 )
+        const char *c_norm_path = svn_dirent_internal_style( path.c_str(), pool );
+        std::string norm_path( c_norm_path );
         svn_error_t *error = svn_wc_adm_probe_open3( &adm_access, NULL, norm_path.c_str(), false, 0, NULL, NULL, pool );
 #else
+        std::string norm_path( svnNormalisedPath( path, pool ) );
         svn_error_t *error = svn_wc_adm_probe_open( &adm_access, NULL, norm_path.c_str(), false, false, pool );
 #endif
 
